__title__ = "gethash"
__version__ = "3.1"
__author__ = "xymy"
__email__ = "thyfan@163.com"
